@@ -10,7 +10,7 @@ use super::Client;
 use crate::client::{connections::QueryResult, errors::Error};
 use crate::messaging::client::{ClientSig, Query};
 use crate::types::{PublicKey, Signature};
-use log::debug;
+use tracing::debug;
 
 impl Client {
     /// Send a Query to the network and await a response
