@@ -54,9 +54,9 @@ impl Core {
                 self.section.prefix()
             );
 
-            let variant = Variant::JoinResponse(Box::new(JoinResponse::Retry(
-                self.section.authority_provider().clone(),
-            )));
+            let redirect_sap = self.matching_section(peer.name())?;
+
+            let variant = Variant::JoinResponse(Box::new(JoinResponse::Retry(redirect_sap)));
             trace!("Sending {:?} to {}", variant, peer);
             return Ok(vec![self.send_direct_message(
                 (*peer.name(), *peer.addr()),
